@@ -167,7 +167,6 @@ drop_moving_chips (gint x, gint y)
 {
   hstack_type hstack;
   gint chipid; 
-  gint width, height;
   gboolean moved = false;
 
   bj_chip_stack_pressed (x, y, &hstack, &chipid);
@@ -198,8 +197,6 @@ drop_moving_chips (gint x, gint y)
               gfloat value = bj_chip_stack_get_chips_value 
                 (chip_stack_press_data->chips);
               bj_adjust_wager (-1 * value);
-              gint x = chip_stack_press_data->hstack->x;
-              gint y = chip_stack_press_data->hstack->y;
               bj_clear_table ();
               moved = true;
             }
@@ -646,9 +643,13 @@ bj_event_configure (GtkWidget *widget, GdkEventConfigure *event)
         return TRUE;
       g_object_unref (surface);
     }
-  else
-    {
-    }
+  
+  if (!draw_gc) {
+    draw_gc = gdk_gc_new (playing_area->window);
+    if (get_background_pixmap ())
+      gdk_gc_set_tile (draw_gc, get_background_pixmap());
+    gdk_gc_set_fill (draw_gc, GDK_TILED);
+  }
 
   surface = gdk_pixmap_new
     (playing_area->window, event->width, event->height,
