@@ -395,7 +395,7 @@ about_cb(GtkWidget *widget, gpointer data)
                           NULL
                           };
   /* Translator credits */
-  gchar *translator_credits = _("translator_credits");
+  gchar *translator_credits = _("translator-credits");
   
   if (about != NULL) {
     gtk_window_present (GTK_WINDOW(about));
@@ -416,12 +416,12 @@ about_cb(GtkWidget *widget, gpointer data)
   }
   
   about = gnome_about_new(_("gataxx"), VERSION,
-			  "Copyright \xc2\xa9 1999-2003 Chris Rogers",
+			  "Copyright \xc2\xa9 1999-2004 Chris Rogers",
   			  _("gataxx is a GNOME port of the old game ataxx. "
 			    "It is derived from Ian Peters' iagno code."),
   			  (const char **)authors,
   			  (const char **)documenters,
-  			  strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+  			  strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 			  pixbuf);
   if (pixbuf != NULL)
 		gdk_pixbuf_unref (pixbuf);
