@@ -23,8 +23,8 @@
 #ifndef _PROPERTIES_H_
 #define _PROPERTIES_H_
 
-void load_properties ();
-void reload_properties ();
-void show_properties_dialog ();
+void load_properties (void);
+void reload_properties (void);
+void show_properties_dialog (void);
 
 #endif
