@@ -66,6 +66,7 @@ enum {
 	LOOK_SIGNAL,
 	UNLOOK_SIGNAL,
 	WIN_SIGNAL,
+	HINT_SIGNAL,
 	LAST_SIGNAL
 };
 
@@ -314,6 +315,8 @@ static void gtk_mine_draw(GtkMineField *mfield, guint x, guint y)
         GtkWidget *widget = GTK_WIDGET(mfield);
 	GdkRectangle rect;
 	
+	g_return_if_fail (c != -1);
+
         /* This gives us a dotted line to increase the contrast between
          * buttons and the "sea". */
         if (stipple == NULL) {
@@ -327,13 +330,9 @@ static void gtk_mine_draw(GtkMineField *mfield, guint x, guint y)
                 
 	minesize = mfield->minesize;
 	
-	if (mfield->lose || mfield->win) {
-		noshadow = mfield->mines[c].shown;
-	} else {
-		noshadow = mfield->mines[c].shown;
-	}
+	noshadow = mfield->mines[c].shown;
 
-	clicked = mfield->mines[c].down;
+	clicked = mfield->mines[c].down; 
 
 	/* gtk_paint_box needs a clipping rectangle. */
 	rect.x = x*minesize;
@@ -343,14 +342,14 @@ static void gtk_mine_draw(GtkMineField *mfield, guint x, guint y)
 
 	if (noshadow) { /* draw grid on ocean floor */
 		gtk_paint_box (widget->style,
-				    widget->window,
-				    GTK_STATE_NORMAL,
-				    clicked ? GTK_SHADOW_IN : GTK_SHADOW_NONE,
-				    &rect,
-				    widget,
-				    "button",
-				    x*minesize, y*minesize,
-				    minesize, minesize);
+			       widget->window,
+			       clicked ? GTK_STATE_ACTIVE : GTK_STATE_NORMAL,
+			       GTK_SHADOW_IN,
+			       &rect,
+			       widget,
+			       "button",
+			       x*minesize, y*minesize,
+			       minesize, minesize);
 		if (y == 0) {	/* top row only */
 			gdk_draw_line(widget->window,	/* top */
 			              dots,
@@ -383,7 +382,7 @@ static void gtk_mine_draw(GtkMineField *mfield, guint x, guint y)
 	} else {	/* draw shadow around possible mine location */
 		gtk_paint_box (widget->style,
 			       widget->window,
-			       GTK_STATE_SELECTED,
+			       clicked ? GTK_STATE_ACTIVE : GTK_STATE_SELECTED,
 			       clicked ? GTK_SHADOW_IN : GTK_SHADOW_OUT,
 			       &rect,
 			       widget,
@@ -634,7 +633,9 @@ static void gtk_minefield_randomize (GtkMineField *mfield, int curloc)
 
 static void gtk_minefield_show(GtkMineField *mfield, guint x, guint y)
 {
-	int c = x + mfield->xsize * y;
+	int c = cell_idx (mfield, x, y);
+
+	g_return_if_fail (c != -1);
 
 	/* make sure first click isn't on a mine */
 	if (!mfield->in_play) {
@@ -662,6 +663,8 @@ static void gtk_minefield_toggle_mark(GtkMineField *mfield, guint x, guint y)
 {
         int c = cell_idx(mfield, x, y);
 
+	g_return_if_fail (c != -1);
+
 	if (mfield->mines[c].shown != 0) { /* nothing to toggle */
 		return;
 	}
@@ -749,7 +752,7 @@ static void gtk_minefield_multi_release (GtkMineField *mfield, guint x, guint y,
                         continue;
                 if (mfield->mines[c2].down) {
                         mfield->mines[c2].down = 0;
-                        if (really) {
+                        if (really && (mfield->mines[c2].shown == 0)) {
 				mfield->mines[c2].shown = 1;
 				mfield->shown++;
                                 if (mfield->mines[c2].mined == 1) {
@@ -794,7 +797,8 @@ static gint gtk_minefield_motion_notify(GtkWidget *widget, GdkEventMotion *event
                 if (x < 0 || y < 0 || x > mfield->xsize-1 || y > mfield->ysize-1)
                         return 0;
 
-                c = x+y*(mfield->xsize);
+                c = cell_idx (mfield, x, y);
+		g_assert (c != -1);
 
                 if (c != mfield->cdown) {
                         mfield->mines[mfield->cdown].down = 0;
@@ -838,7 +842,8 @@ static gint gtk_minefield_button_press(GtkWidget *widget, GdkEventButton *event)
         if (event->button <= 3 && !mfield->bdown[1]) {
                 x = event->x/minesize;
                 y = event->y/minesize;
-                c = x+y*(mfield->xsize);
+                c = cell_idx (mfield, x, y);
+		if (c == -1) return FALSE;
                 if (!mfield->bdown[0] && !mfield->bdown[1] && !mfield->bdown[2]) {
                         mfield->cdownx = x;
                         mfield->cdowny = y;
@@ -975,6 +980,16 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 			       g_cclosure_marshal_VOID__VOID,
 			       G_TYPE_NONE,
 			       0);
+	minefield_signals[HINT_SIGNAL] =
+		g_signal_new("hint-used",
+			       G_OBJECT_CLASS_TYPE (object_class),
+			       G_SIGNAL_RUN_FIRST,
+			       G_STRUCT_OFFSET(GtkMineFieldClass, hint_used),
+			       NULL, NULL,
+			       g_cclosure_marshal_VOID__VOID,
+			       G_TYPE_NONE,
+			       0);
+
 }
 
 static void gtk_minefield_init (GtkMineField *mfield)
@@ -1168,6 +1183,12 @@ gint gtk_minefield_hint (GtkMineField *mfield)
 	x = i % mfield->xsize;
 	y = i / mfield->xsize;
 
+	/* Makes sure that the program knows about the successful
+	 * hint before a possible win. */
+        g_signal_emit(GTK_OBJECT(mfield),
+                        minefield_signals[HINT_SIGNAL],
+			0, NULL);
+
 	gtk_minefield_show (mfield, x, y);
 	gtk_mine_draw (mfield, x, y);
 	return MINEFIELD_HINT_ACCEPTED;
